@@ -8,8 +8,8 @@
 #' Graphics and plots are managed using functions contained in the package \strong{ggplot2} and \strong{ggthemes}.
 #' @keywords diagnostics MCMC convergence checks
 #' @param x An object of class "missingHE" containing the posterior results of a full Bayesian model implemented using the function \code{\link{selection}}, 
-#' \code{\link{pattern}} or \code{\link{hurdle}}
-#' @param type Type of diagnostic check to be plotted for the model parameter selected Available choices include: 'histogram' for histogram plots,
+#' \code{\link{pattern}} or \code{\link{hurdle}}.
+#' @param type Type of diagnostic check to be plotted for the model parameter selected. Available choices include: 'histogram' for histogram plots,
 #' 'denplot' for density plots, 'traceplot' for trace plots, 'acf' for autocorrelation plots, 'running' for running mean plots,
 #' 'compare' for comparing the distribution of the whole chain with only its last part, 'cross' for crosscorrelation plots, 'Rhat' for the potential scale reduction factor, 'geweke' for the geweke diagnostic,
 #' 'pairs' for posterior correlation among the parameters,'caterpillar' for caterpillar plots. In addition the class 'summary' provides an overview of some of the most popular
@@ -58,20 +58,19 @@
 #' can be accessed only when \code{x} is created using the function \code{hurdle}.
 #' 
 #' The argument \code{theme} allows to customise the graphical output of the plots generated by \code{diagnostic} and
-#' allows to choose among a set of possible pre-defined themes taken form the package \strong{ggtheme}. Those available can
-#' be indicated using one of the following character names: "base","calc","economist","excel","few","538","gdocs","hc","par","pander","solarized","stata","tufte","wsj".
+#' allows to choose among a set of possible pre-defined themes taken form the package \strong{ggtheme}. For a complete list of the available character names
+#' for each theme, see \strong{ggthemes}.
 #' 
 #' @author Andrea Gabrio
 #' @references 
 #' Gelman, A. Carlin, JB., Stern, HS. Rubin, DB.(2003). \emph{Bayesian Data Analysis, 2nd edition}, CRC Press.
 #'
 #' Brooks, S. Gelman, A. Jones, JL. Meng, XL. (2011). \emph{Handbook of Markov Chain Monte Carlo}, CRC/Chapman and Hall.
-#' @import ggplot2 coda mcmcr
+#' @import ggplot2 coda 
 #' @importFrom stats quantile
 #' @export 
 #' @examples 
-#' # For examples see the function \code{\link{selection}}, 
-#' # \code{\link{pattern}} or \code{\link{hurdle}}
+#' #For examples see the function selection, pattern or hurdle
 #' #
 #' #
 
@@ -170,7 +169,67 @@ diagnostic <- function(x, type = "histogram", param = "all", theme = NULL, ...)
   check_index_loglik <- which(check_name_loglik, TRUE)
   check_name_deviance <- grepl("dev", v_name)
   check_index_deviance <- which(check_name_deviance, TRUE)
+  if(x$model_output$ppc == TRUE) {
+    if(x$model_output$dist_e == "norm") {
+      check_name_params_e_ppc1 <- grepl("mu_e1",v_name)
+      check_name_params_e_ppc2 <- grepl("mu_e2",v_name)
+      check_name_params_e_ppc3 <- rep(FALSE, length(v_name))
+      check_name_params_e_ppc4 <- rep(FALSE, length(v_name))
+      if(grepl("SELECTION", x$model_output$type) == TRUE){
+        check_name_params_e_ppc3 <- grepl("tau_e",v_name)
+      } else if(grepl("PATTERN", x$model_output$type) == TRUE) {
+        check_name_params_e_ppc3 <- grepl("tau_e_p1",v_name)
+        check_name_params_e_ppc4 <- grepl("tau_e_p2",v_name)
+      } else if(grepl("HURDLE", x$model_output$type) == TRUE) {
+        check_name_params_e_ppc3 <- grepl("tau_e1",v_name)
+        check_name_params_e_ppc4 <- grepl("tau_e2",v_name)
+      }
+    } else if(x$model_output$dist_e == "beta") {
+      check_name_params_e_ppc1 <- grepl("mu_e1",v_name)
+      check_name_params_e_ppc2 <- grepl("mu_e2",v_name)
+      check_name_params_e_ppc3 <- grepl("tau_e1",v_name)
+      check_name_params_e_ppc4 <- grepl("tau_e2",v_name)
+    }
+    check_index_params_e_ppc <- c(which(check_name_params_e_ppc1, TRUE), which(check_name_params_e_ppc2, TRUE), which(check_name_params_e_ppc3, TRUE), which(check_name_params_e_ppc4, TRUE))
+    if(x$model_output$dist_c == "norm") {
+      check_name_params_c_ppc1 <- grepl("mu_c1",v_name)
+      check_name_params_c_ppc2 <- grepl("mu_c2",v_name)
+      check_name_params_c_ppc3 <- rep(FALSE, length(v_name))
+      check_name_params_c_ppc4 <- rep(FALSE, length(v_name))
+      if(grepl("SELECTION", x$model_output$type) == TRUE){
+        check_name_params_c_ppc3 <- grepl("tau_c",v_name)
+      } else if(grepl("PATTERN", x$model_output$type) == TRUE) {
+        check_name_params_c_ppc3 <- grepl("tau_c_p1",v_name)
+        check_name_params_c_ppc4 <- grepl("tau_c_p2",v_name)
+      } else if(grepl("HURDLE", x$model_output$type) == TRUE) {
+        check_name_params_c_ppc3 <- grepl("tau_c1",v_name)
+        check_name_params_c_ppc4 <- grepl("tau_c2",v_name)
+      }
+    } else if(x$model_output$dist_c == "gamma") {
+      check_name_params_c_ppc1 <- grepl("mu_c1",v_name)
+      check_name_params_c_ppc2 <- grepl("mu_c2",v_name)
+      check_name_params_c_ppc3 <- grepl("tau_c1",v_name)
+      check_name_params_c_ppc4 <- grepl("tau_c2",v_name)
+      check_index_params_c_ppc <- c(which(check_name_params_c_ppc1, TRUE), which(check_name_params_c_ppc2, TRUE), which(check_name_params_c_ppc3, TRUE), which(check_name_params_c_ppc4, TRUE))
+    } else if(x$model_output$dist_c == "lnorm") {
+      check_name_params_c_ppc1 <- grepl("lmu_c1",v_name)
+      check_name_params_c_ppc2 <- grepl("lmu_c2",v_name)
+      check_name_params_c_ppc3 <- rep(FALSE, length(v_name))
+      check_name_params_c_ppc4 <- rep(FALSE, length(v_name))
+      if(grepl("SELECTION", x$model_output$type) == TRUE){
+        check_name_params_c_ppc3 <- grepl("ltau_c",v_name)
+      } else if(grepl("PATTERN", x$model_output$type) == TRUE) {
+        check_name_params_c_ppc3 <- grepl("ltau_c_p1",v_name)
+        check_name_params_c_ppc4 <- grepl("ltau_c_p2",v_name)
+      } else if(grepl("HURDLE", x$model_output$type) == TRUE) {
+        check_name_params_c_ppc3 <- grepl("ltau_c1",v_name)
+        check_name_params_c_ppc4 <- grepl("ltau_c2",v_name)
+      }
+    }
+    check_index_params_c_ppc <- c(which(check_name_params_c_ppc1, TRUE), which(check_name_params_c_ppc2, TRUE), which(check_name_params_c_ppc3, TRUE), which(check_name_params_c_ppc4, TRUE))
+  }
   check_index <- c(check_index_cost, check_index_eff, check_index_loglik, check_index_deviance)
+  if(x$model_output$ppc == TRUE) {check_index <- c(check_index, check_index_params_e_ppc, check_index_params_c_ppc) }
   parameters <- v_name[-check_index]
   parameters <- gsub("\\[|\\]", "", parameters)
   parameters <- gsub('[[:digit:]]+', '', parameters)
