@@ -1,7 +1,7 @@
 #' Full Bayesian Models to handle missingness in Economic Evaluations (Hurdle Models)
 #' 
 #' Full Bayesian cost-effectiveness models to handle missing data in the outcomes using Hurdle models
-#' under alternative parametric distributions for the effect and cost variables. Alternative
+#' under a variatey of alternative parametric distributions for the effect and cost variables. Alternative
 #' assumptions about the mechanisms of the structural values are implemented using a hurdle approach. The analysis is performed using the \code{BUGS} language, 
 #' which is implemented in the software \code{JAGS} using the function \code{\link[R2jags]{jags}}. The output is stored in an object of class 'missingHE'.
 #' 
@@ -27,8 +27,8 @@
 #' no structural value is chosen and a standard model for the effects is run.
 #' @param sc Structural value to be found in the cost variables defined in \code{data}. If set to \code{NULL}, 
 #' no structural value is chosen and a standard model for the costs is run.
-#' @param dist_e Distribution assumed for the effects. Current available choices are: Normal ('norm') or Beta ('beta').
-#' @param dist_c Distribution assumed for the costs. Current available choices are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm').
+#' @param dist_e Distribution assumed for the effects. Current available chocies are: Normal ('norm') or Beta ('beta').
+#' @param dist_c Distribution assumed for the costs. Current available chocies are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm').
 #' @param type Type of structural value mechanism assumed. Choices are Structural Completely At Random (SCAR),
 #' and Structural At Random (SAR).
 #' @param prob A numeric vector of probabilities within the range (0,1), representing the upper and lower
@@ -40,6 +40,7 @@
 #' \code{JAGS} model, or a function creating (possibly random) initial values. If \code{inits} is \code{NULL}, \code{JAGS}
 #' will generate initial values for all the model parameters.
 #' @param n.thin Thinning interval.
+#' @param ppc Logical. If \code{ppc} is \code{TRUE}, the estimates of the parameters that can be used to generate replications from the model are saved.
 #' @param save_model Logical. If \code{save_model} is \code{TRUE} a \code{txt} file containing the model code is printed
 #' in the current working directory.
 #' @param prior A list containing the hyperprior values provided by the user. Each element of this list must be a vector of length two
@@ -119,13 +120,13 @@
 #'
 #' @examples
 #' # Quck example to run using subset of MenSS dataset
-#' MenSS.subset <- MenSS[1:80, ]
+#' MenSS.subset <- MenSS[50:100, ]
 #' 
 #' # Run the model using the hurdle function assuming a SCAR mechanism
 #' # Use only 100 iterations to run a quick check
 #' model.hurdle <- hurdle(data = MenSS.subset, model.eff = e ~ 1,model.cost = c ~ 1,
 #'    model.se = se ~ 1, model.sc = sc ~ 1, se = 1, sc = 0, dist_e = "norm", dist_c = "norm",
-#'    type = "SCAR", n.chains = 2, n.iter = 100)
+#'    type = "SCAR", n.chains = 2, n.iter = 100,  ppc = FALSE)
 #' 
 #' # Print the results of the JAGS model
 #' print(model.hurdle)
@@ -159,7 +160,7 @@
 #' # Further examples which take longer to run
 #' model.hurdle <- hurdle(data = MenSS, model.eff = e ~ u.0,model.cost = c ~ e,
 #'    model.se = se ~ u.0, model.sc = sc ~ 1, se = 1, sc = 0, dist_e = "norm", dist_c = "norm",
-#'    type = "SAR", n.chains = 2, n.iter = 1000)
+#'    type = "SAR", n.chains = 2, n.iter = 500,  ppc = FALSE)
 #' #
 #' # Print results for all imputed values
 #' print(model.hurdle, value.mis = TRUE)
@@ -184,7 +185,7 @@
 
 hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc ~ 1, se = 1, sc = 0, 
                    dist_e, dist_c, type, prob = c(0.05, 0.95), n.chains = 2, n.iter = 20000, 
-                   n.burnin = floor(n.iter / 2), inits = NULL, n.thin = 1, save_model = FALSE, prior = "default", ...) {
+                   n.burnin = floor(n.iter / 2), inits = NULL, n.thin = 1, ppc = FALSE, save_model = FALSE, prior = "default", ...) {
   filein <- NULL
   if(is.data.frame(data) == FALSE) {
     stop("data must be in data frame format")
@@ -222,8 +223,8 @@ hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc
   if(length(prob) != 2 | is.numeric(prob) == FALSE | any(prob < 0) != FALSE | any(prob > 1) != FALSE) {
     stop("You must provide valid lower/upper quantiles for the imputed data distribution")
   }
-  if(is.logical(save_model) == FALSE) {
-    stop("save_model should be either TRUE or FALSE")
+  if(is.logical(save_model) == FALSE | is.logical(ppc) == FALSE) {
+    stop("save_model and ppc are logical arguments and should be either TRUE or FALSE")
   }
   exArgs <- list(...)
   if(exists("center", where = exArgs)) {
@@ -445,7 +446,7 @@ hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc
                        "structural_effects" = data_read$structural_effects, "structural_costs" = data_read$structural_costs, 
                        "missing_effects" = data_read$missing_effects, "missing_costs" = data_read$missing_costs)
     }
-  model_output <- run_hurdle(type = type, dist_e = dist_e, dist_c = dist_c, inits = inits, se = se, sc = sc, sde = sde, sdc = sdc)
+  model_output <- run_hurdle(type = type, dist_e = dist_e, dist_c = dist_c, inits = inits, se = se, sc = sc, sde = sde, sdc = sdc, ppc = ppc)
   if(save_model == FALSE) {
     unlink(filein)
   }
